
import { useState, useEffect } from 'react';
import { CreditCard } from 'lucide-react';
import { Switch } from "@/components/ui/switch";
import { Label } from "@/components/ui/label";
import { Input } from "@/components/ui/input";
import { 
  Select, 
  SelectContent, 
  SelectItem, 
  SelectTrigger, 
  SelectValue 
} from "@/components/ui/select";

interface CreditHistoryProps {
  formData: any;
  setFormData: (data: any) => void;
}

export const CreditHistorySection = ({ formData, setFormData }: CreditHistoryProps) => {
  const [hasCreditCard, setHasCreditCard] = useState(true);
  const [hasLoan, setHasLoan] = useState(true);
  const [selectedCreditCardMonth, setSelectedCreditCardMonth] = useState<string | null>(null);
  const [selectedLoanMonth, setSelectedLoanMonth] = useState<string | null>(null);
  
  const months = [
    "January", "February", "March", "April", "May", "June", 
    "July", "August", "September", "October", "November", "December"
  ];

  useEffect(() => {
    if (formData.hasCreditCard !== undefined) {
      setHasCreditCard(formData.hasCreditCard);
    }
    
    if (formData.hasLoan !== undefined) {
      setHasLoan(formData.hasLoan);
    }
  }, [formData.hasCreditCard, formData.hasLoan]);

  const handleCreditCardChange = (e: boolean) => {
    const hasCard = e;
    setHasCreditCard(hasCard);
    setFormData(prev => ({ 
      ...prev, 
      hasCreditCard: hasCard,
      // If setting to false, clear credit card payment history
      creditCardDelayDays: hasCard ? (prev.creditCardDelayDays || {}) : {}
    }));
  };

  const handleLoanChange = (e: boolean) => {
    const hasLoanValue = e;
    setHasLoan(hasLoanValue);
    setFormData(prev => ({ 
      ...prev, 
      hasLoan: hasLoanValue,
      // If setting to false, clear loan payment history
      loanDelayDays: hasLoanValue ? (prev.loanDelayDays || {}) : {}
    }));
  };

  const handleCreditCardDelayChange = (month: string, value: string) => {
    setFormData(prev => {
      const updatedDelayDays = { ...(prev.creditCardDelayDays || {}) };
      updatedDelayDays[month] = value;
      
      return {
        ...prev,
        creditCardDelayDays: updatedDelayDays
      };
    });
  };

  const handleLoanDelayChange = (month: string, value: string) => {
    setFormData(prev => {
      const updatedDelayDays = { ...(prev.loanDelayDays || {}) };
      updatedDelayDays[month] = value;
      
      return {
        ...prev,
        loanDelayDays: updatedDelayDays
      };
    });
  };

  const handleCreditLimitChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { value } = e.target;
    setFormData(prev => ({
      ...prev,
      existingCreditCardLimit: value
    }));
  };

  const handleLoanAmountChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { value } = e.target;
    setFormData(prev => ({
      ...prev,
      existingLoanAmount: value
    }));
  };

  return (
    <div className="glass-panel p-6 animate-fade-up" style={{ animationDelay: '0.3s' }}>
      <div className="flex items-center gap-2 mb-6">
        <div className="w-8 h-8 rounded-full bg-brand-blue/10 flex items-center justify-center">
          <CreditCard className="w-4 h-4 text-brand-blue" />
        </div>
        <h3 className="font-semibold text-lg">Credit History</h3>
      </div>

      <div className="space-y-6">
        {/* Credit Card Section */}
        <div className="border-b border-border/50 pb-6">
          <div className="flex flex-col md:flex-row md:items-center md:justify-between mb-4 gap-4">
            <div className="flex items-center space-x-2">
              <Switch 
                id="hasCreditCard" 
                checked={hasCreditCard}
                onCheckedChange={handleCreditCardChange}
              />
              <Label htmlFor="hasCreditCard">Client has a credit card</Label>
            </div>
            
            {hasCreditCard && (
              <div className="flex items-center space-x-2">
                <Label htmlFor="existingCreditCardLimit">Existing Credit Card Limit (BDT)</Label>
                <Input 
                  id="existingCreditCardLimit" 
                  type="number"
                  placeholder="50000"
                  className="w-32"
                  value={formData.existingCreditCardLimit || ''}
                  onChange={handleCreditLimitChange}
                />
              </div>
            )}
          </div>

          {hasCreditCard && (
            <div>
              <h4 className="text-md font-medium mb-3">Credit Card Payment History (Delay Days)</h4>
              <div className="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                <div>
                  <Label htmlFor="creditCardMonth" className="mb-2 block">Select Month</Label>
                  <Select 
                    value={selectedCreditCardMonth || ''} 
                    onValueChange={setSelectedCreditCardMonth}
                  >
                    <SelectTrigger id="creditCardMonth" className="w-full">
                      <SelectValue placeholder="Select month" />
                    </SelectTrigger>
                    <SelectContent>
                      {months.map((month) => (
                        <SelectItem key={month} value={month}>{month}</SelectItem>
                      ))}
                    </SelectContent>
                  </Select>
                </div>
                
                {selectedCreditCardMonth && (
                  <div>
                    <Label htmlFor="creditCardDelayDays" className="mb-2 block">Delay Days</Label>
                    <Input
                      id="creditCardDelayDays"
                      type="number"
                      placeholder="0"
                      className="w-full"
                      value={formData.creditCardDelayDays && formData.creditCardDelayDays[selectedCreditCardMonth] ? formData.creditCardDelayDays[selectedCreditCardMonth] : ''}
                      onChange={(e) => handleCreditCardDelayChange(selectedCreditCardMonth, e.target.value)}
                    />
                  </div>
                )}
              </div>
              
              {/* Display entered delay days */}
              {formData.creditCardDelayDays && Object.keys(formData.creditCardDelayDays).length > 0 && (
                <div className="mt-4">
                  <h4 className="text-sm font-medium mb-2">Entered Delay Days:</h4>
                  <div className="grid grid-cols-2 md:grid-cols-4 gap-2">
                    {Object.entries(formData.creditCardDelayDays || {}).map(([month, days]) => (
                      <div key={month} className="bg-muted/50 p-2 rounded-md text-sm">
                        <span className="font-medium">{month}:</span> {String(days)} days
                      </div>
                    ))}
                  </div>
                </div>
              )}
            </div>
          )}
        </div>
        
        {/* Loan Section */}
        <div>
          <div className="flex flex-col md:flex-row md:items-center md:justify-between mb-4 gap-4">
            <div className="flex items-center space-x-2">
              <Switch 
                id="hasLoan" 
                checked={hasLoan}
                onCheckedChange={handleLoanChange}
              />
              <Label htmlFor="hasLoan">Client has a loan</Label>
            </div>
            
            {hasLoan && (
              <div className="flex items-center space-x-2">
                <Label htmlFor="existingLoanAmount">Existing Loan Amount (BDT)</Label>
                <Input 
                  id="existingLoanAmount" 
                  type="number"
                  placeholder="100000"
                  className="w-32"
                  value={formData.existingLoanAmount || ''}
                  onChange={handleLoanAmountChange}
                />
              </div>
            )}
          </div>

          {hasLoan && (
            <div>
              <h4 className="text-md font-medium mb-3">Loan Payment History (Delay Days)</h4>
              <div className="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                <div>
                  <Label htmlFor="loanMonth" className="mb-2 block">Select Month</Label>
                  <Select 
                    value={selectedLoanMonth || ''} 
                    onValueChange={setSelectedLoanMonth}
                  >
                    <SelectTrigger id="loanMonth" className="w-full">
                      <SelectValue placeholder="Select month" />
                    </SelectTrigger>
                    <SelectContent>
                      {months.map((month) => (
                        <SelectItem key={month} value={month}>{month}</SelectItem>
                      ))}
                    </SelectContent>
                  </Select>
                </div>
                
                {selectedLoanMonth && (
                  <div>
                    <Label htmlFor="loanDelayDays" className="mb-2 block">Delay Days</Label>
                    <Input
                      id="loanDelayDays"
                      type="number"
                      placeholder="0"
                      className="w-full"
                      value={formData.loanDelayDays && formData.loanDelayDays[selectedLoanMonth] ? formData.loanDelayDays[selectedLoanMonth] : ''}
                      onChange={(e) => handleLoanDelayChange(selectedLoanMonth, e.target.value)}
                    />
                  </div>
                )}
              </div>
              
              {/* Display entered delay days */}
              {formData.loanDelayDays && Object.keys(formData.loanDelayDays).length > 0 && (
                <div className="mt-4">
                  <h4 className="text-sm font-medium mb-2">Entered Delay Days:</h4>
                  <div className="grid grid-cols-2 md:grid-cols-4 gap-2">
                    {Object.entries(formData.loanDelayDays || {}).map(([month, days]) => (
                      <div key={month} className="bg-muted/50 p-2 rounded-md text-sm">
                        <span className="font-medium">{month}:</span> {String(days)} days
                      </div>
                    ))}
                  </div>
                </div>
              )}
            </div>
          )}
        </div>
      </div>
    </div>
  );
};
